==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Dependency.java <==
package software.amazon.awscdk.core;

/**
 * A single dependency.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.907Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Dependency extends software.amazon.jsii.JsiiSerializable {
    /**
     * Source the dependency.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getSource();

    /**
     * Target of the dependency.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getTarget();

    /**
     * @return a {@link Builder} of {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private software.amazon.awscdk.core.IConstruct source;
        private software.amazon.awscdk.core.IConstruct target;

        /**
         * Sets the value of Source
         * @param source Source the dependency.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder source(software.amazon.awscdk.core.IConstruct source) {
            this.source = source;
            return this;
        }

        /**
         * Sets the value of Target
         * @param target Target of the dependency.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder target(software.amazon.awscdk.core.IConstruct target) {
            this.target = target;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Dependency}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Dependency build() {
            return new Jsii$Proxy(source, target);
        }

    }

    /**
     * An implementation for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Dependency {
        private final software.amazon.awscdk.core.IConstruct source;
        private final software.amazon.awscdk.core.IConstruct target;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.source = this.jsiiGet("source", software.amazon.awscdk.core.IConstruct.class);
            this.target = this.jsiiGet("target", software.amazon.awscdk.core.IConstruct.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.core.IConstruct source, software.amazon.awscdk.core.IConstruct target) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.source = java.util.Objects.requireNonNull(source, "source is required");
            this.target = java.util.Objects.requireNonNull(target, "target is required");
        }

        @Override
        public software.amazon.awscdk.core.IConstruct getSource() {
            return this.source;
        }

        @Override
        public software.amazon.awscdk.core.IConstruct getTarget() {
            return this.target;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("source", om.valueToTree(this.getSource()));
            obj.set("target", om.valueToTree(this.getTarget()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Dependency.Jsii$Proxy that = (Dependency.Jsii$Proxy) o;

            if (!source.equals(that.source)) return false;
            return this.target.equals(that.target);
        }

        @Override
        public int hashCode() {
            int result = this.source.hashCode();
            result = 31 * result + (this.target.hashCode());
            return result;
        }

    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Dependency.java <==
package software.amazon.awscdk.core;

/**
 * A single dependency.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.456Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Dependency extends software.amazon.jsii.JsiiSerializable {

    /**
     * Source the dependency.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getSource();

    /**
     * Target of the dependency.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getTarget();

    /**
     * @return a {@link Builder} of {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.core.IConstruct source;
        private software.amazon.awscdk.core.IConstruct target;

        /**
         * Sets the value of Source
         * @param source Source the dependency. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder source(software.amazon.awscdk.core.IConstruct source) {
            this.source = source;
            return this;
        }

        /**
         * Sets the value of Target
         * @param target Target of the dependency. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder target(software.amazon.awscdk.core.IConstruct target) {
            this.target = target;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Dependency}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Dependency build() {
            return new Jsii$Proxy(source, target);
        }
    }

    /**
     * An implementation for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Dependency {
        private final software.amazon.awscdk.core.IConstruct source;
        private final software.amazon.awscdk.core.IConstruct target;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.source = this.jsiiGet("source", software.amazon.awscdk.core.IConstruct.class);
            this.target = this.jsiiGet("target", software.amazon.awscdk.core.IConstruct.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.core.IConstruct source, software.amazon.awscdk.core.IConstruct target) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.source = java.util.Objects.requireNonNull(source, "source is required");
            this.target = java.util.Objects.requireNonNull(target, "target is required");
        }

        @Override
        public software.amazon.awscdk.core.IConstruct getSource() {
            return this.source;
        }

        @Override
        public software.amazon.awscdk.core.IConstruct getTarget() {
            return this.target;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("source", om.valueToTree(this.getSource()));
            obj.set("target", om.valueToTree(this.getTarget()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Dependency.Jsii$Proxy that = (Dependency.Jsii$Proxy) o;

            if (!source.equals(that.source)) return false;
            return this.target.equals(that.target);
        }

        @Override
        public int hashCode() {
            int result = this.source.hashCode();
            result = 31 * result + (this.target.hashCode());
            return result;
        }
    }
}
